/*****************************************************************************\
  breaks_open.cpp : Open Source Imaging Error Diffusion Tables

  Copyright (c) 1994 - 2001, Hewlett-Packard Co.
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of Hewlett-Packard nor the names of its
     contributors may be used to endorse or promote products derived
     from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN
  NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
  TO, PATENT INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\*****************************************************************************/


#ifdef APDK_PROTO
#include "..\common\config.h"
#include "..\common\resources.h"
#else
#include "config.h"
#include "resources.h"
#endif

APDK_BEGIN_NAMESPACE

const unsigned char HTBinary_open[1024]=
{
   0 ,    0 ,    0 ,    0 ,
   0 ,    0 ,    0 ,    0 ,
   0 ,    2 ,    0 ,    0 ,
   0 ,    3 ,    0 ,    0 ,
   0 ,    4 ,    0 ,    0 ,
   0 ,    5 ,    0 ,    0 ,
   0 ,    6 ,    0 ,    0 ,
   0 ,    7 ,    0 ,    0 ,
   0 ,    8 ,    0 ,    0 ,
   0 ,    9 ,    0 ,    0 ,
   0 ,   10 ,    0 ,    0 ,
   0 ,   11 ,    0 ,    0 ,
   0 ,   12 ,    0 ,    0 ,
   0 ,   13 ,    0 ,    0 ,
   0 ,   14 ,    0 ,    0 ,
   0 ,   15 ,    0 ,    0 ,
   0 ,   16 ,    0 ,    0 ,
   0 ,   17 ,    0 ,    0 ,
   0 ,   18 ,    0 ,    0 ,
   0 ,   19 ,    0 ,    0 ,
   0 ,   20 ,    0 ,    0 ,
   0 ,   21 ,    0 ,    0 ,
   0 ,   22 ,    0 ,    0 ,
   0 ,   23 ,    0 ,    0 ,
   0 ,   24 ,    0 ,    0 ,
   0 ,   25 ,    0 ,    0 ,
   0 ,   26 ,    0 ,    0 ,
   0 ,   27 ,    0 ,    0 ,
   0 ,   28 ,    0 ,    0 ,
   0 ,   29 ,    0 ,    0 ,
   0 ,   30 ,    0 ,    0 ,
   0 ,   31 ,    0 ,    0 ,
   0 ,   32 ,    0 ,    0 ,
   0 ,   33 ,    0 ,    0 ,
   0 ,   34 ,    0 ,    0 ,
   0 ,   35 ,    0 ,    0 ,
   0 ,   36 ,    0 ,    0 ,
   0 ,   37 ,    0 ,    0 ,
   0 ,   38 ,    0 ,    0 ,
   0 ,   39 ,    0 ,    0 ,
   0 ,   40 ,    0 ,    0 ,
   0 ,   41 ,    0 ,    0 ,
   0 ,   42 ,    0 ,    0 ,
   0 ,   43 ,    0 ,    0 ,
   0 ,   44 ,    0 ,    0 ,
   0 ,   45 ,    0 ,    0 ,
   0 ,   46 ,    0 ,    0 ,
   0 ,   47 ,    0 ,    0 ,
   0 ,   48 ,    0 ,    0 ,
   0 ,   49 ,    0 ,    0 ,
   0 ,   50 ,    0 ,    0 ,
   0 ,   51 ,    0 ,    0 ,
   0 ,   52 ,    0 ,    0 ,
   0 ,   53 ,    0 ,    0 ,
   0 ,   54 ,    0 ,    0 ,
   0 ,   55 ,    0 ,    0 ,
   0 ,   56 ,    0 ,    0 ,
   0 ,   57 ,    0 ,    0 ,
   0 ,   58 ,    0 ,    0 ,
   0 ,   59 ,    0 ,    0 ,
   0 ,   60 ,    0 ,    0 ,
   0 ,   61 ,    0 ,    0 ,
   0 ,   62 ,    0 ,    0 ,
   0 ,   63 ,    0 ,    0 ,
   0 ,   64 ,    0 ,    0 ,
   0 ,   65 ,    0 ,    0 ,
   0 ,   66 ,    0 ,    0 ,
   0 ,   67 ,    0 ,    0 ,
   0 ,   68 ,    0 ,    0 ,
   0 ,   69 ,    0 ,    0 ,
   0 ,   70 ,    0 ,    0 ,
   0 ,   71 ,    0 ,    0 ,
   0 ,   72 ,    0 ,    0 ,
   0 ,   73 ,    0 ,    0 ,
   0 ,   74 ,    0 ,    0 ,
   0 ,   75 ,    0 ,    0 ,
   0 ,   76 ,    0 ,    0 ,
   0 ,   77 ,    0 ,    0 ,
   0 ,   78 ,    0 ,    0 ,
   0 ,   79 ,    0 ,    0 ,
   0 ,   80 ,    0 ,    0 ,
   0 ,   81 ,    0 ,    0 ,
   0 ,   82 ,    0 ,    0 ,
   0 ,   83 ,    0 ,    0 ,
   0 ,   84 ,    0 ,    0 ,
   0 ,   85 ,    0 ,    0 ,
   0 ,   86 ,    0 ,    0 ,
   0 ,   87 ,    0 ,    0 ,
   0 ,   88 ,    0 ,    0 ,
   0 ,   89 ,    0 ,    0 ,
   0 ,   90 ,    0 ,    0 ,
   0 ,   91 ,    0 ,    0 ,
   0 ,   92 ,    0 ,    0 ,
   0 ,   93 ,    0 ,    0 ,
   0 ,   94 ,    0 ,    0 ,
   0 ,   95 ,    0 ,    0 ,
   0 ,   96 ,    0 ,    0 ,
   0 ,   97 ,    0 ,    0 ,
   0 ,   98 ,    0 ,    0 ,
   0 ,   99 ,    0 ,    0 ,
   0 ,  100 ,    0 ,    0 ,
   0 ,  101 ,    0 ,    0 ,
   0 ,  102 ,    0 ,    0 ,
   0 ,  103 ,    0 ,    0 ,
   0 ,  104 ,    0 ,    0 ,
   0 ,  105 ,    0 ,    0 ,
   0 ,  106 ,    0 ,    0 ,
   0 ,  107 ,    0 ,    0 ,
   0 ,  108 ,    0 ,    0 ,
   0 ,  109 ,    0 ,    0 ,
   0 ,  110 ,    0 ,    0 ,
   0 ,  111 ,    0 ,    0 ,
   0 ,  112 ,    0 ,    0 ,
   0 ,  113 ,    0 ,    0 ,
   0 ,  114 ,    0 ,    0 ,
   0 ,  115 ,    0 ,    0 ,
   0 ,  116 ,    0 ,    0 ,
   0 ,  117 ,    0 ,    0 ,
   0 ,  118 ,    0 ,    0 ,
   0 ,  119 ,    0 ,    0 ,
   0 ,  120 ,    0 ,    0 ,
   0 ,  121 ,    0 ,    0 ,
   0 ,  122 ,    0 ,    0 ,
   0 ,  123 ,    0 ,    0 ,
   0 ,  124 ,    0 ,    0 ,
   0 ,  125 ,    0 ,    0 ,
   0 ,  126 ,    0 ,    0 ,
   0 ,  127 ,    0 ,    0 ,
   0 ,  128 ,    0 ,    0 ,
   0 ,  129 ,    0 ,    0 ,
   0 ,  130 ,    0 ,    0 ,
   0 ,  131 ,    0 ,    0 ,
   0 ,  132 ,    0 ,    0 ,
   0 ,  133 ,    0 ,    0 ,
   0 ,  134 ,    0 ,    0 ,
   0 ,  135 ,    0 ,    0 ,
   0 ,  136 ,    0 ,    0 ,
   0 ,  137 ,    0 ,    0 ,
   0 ,  138 ,    0 ,    0 ,
   0 ,  139 ,    0 ,    0 ,
   0 ,  140 ,    0 ,    0 ,
   0 ,  141 ,    0 ,    0 ,
   0 ,  142 ,    0 ,    0 ,
   0 ,  143 ,    0 ,    0 ,
   0 ,  144 ,    0 ,    0 ,
   0 ,  145 ,    0 ,    0 ,
   0 ,  146 ,    0 ,    0 ,
   0 ,  147 ,    0 ,    0 ,
   0 ,  148 ,    0 ,    0 ,
   0 ,  149 ,    0 ,    0 ,
   0 ,  150 ,    0 ,    0 ,
   0 ,  151 ,    0 ,    0 ,
   0 ,  152 ,    0 ,    0 ,
   0 ,  153 ,    0 ,    0 ,
   0 ,  154 ,    0 ,    0 ,
   0 ,  155 ,    0 ,    0 ,
   0 ,  156 ,    0 ,    0 ,
   0 ,  157 ,    0 ,    0 ,
   0 ,  158 ,    0 ,    0 ,
   0 ,  159 ,    0 ,    0 ,
   0 ,  160 ,    0 ,    0 ,
   0 ,  161 ,    0 ,    0 ,
   0 ,  162 ,    0 ,    0 ,
   0 ,  163 ,    0 ,    0 ,
   0 ,  164 ,    0 ,    0 ,
   0 ,  165 ,    0 ,    0 ,
   0 ,  166 ,    0 ,    0 ,
   0 ,  167 ,    0 ,    0 ,
   0 ,  168 ,    0 ,    0 ,
   0 ,  169 ,    0 ,    0 ,
   0 ,  170 ,    0 ,    0 ,
   0 ,  171 ,    0 ,    0 ,
   0 ,  172 ,    0 ,    0 ,
   0 ,  173 ,    0 ,    0 ,
   0 ,  174 ,    0 ,    0 ,
   0 ,  175 ,    0 ,    0 ,
   0 ,  176 ,    0 ,    0 ,
   0 ,  177 ,    0 ,    0 ,
   0 ,  178 ,    0 ,    0 ,
   0 ,  179 ,    0 ,    0 ,
   0 ,  180 ,    0 ,    0 ,
   0 ,  181 ,    0 ,    0 ,
   0 ,  182 ,    0 ,    0 ,
   0 ,  183 ,    0 ,    0 ,
   0 ,  184 ,    0 ,    0 ,
   0 ,  185 ,    0 ,    0 ,
   0 ,  186 ,    0 ,    0 ,
   0 ,  187 ,    0 ,    0 ,
   0 ,  188 ,    0 ,    0 ,
   0 ,  189 ,    0 ,    0 ,
   0 ,  190 ,    0 ,    0 ,
   0 ,  191 ,    0 ,    0 ,
   0 ,  192 ,    0 ,    0 ,
   0 ,  193 ,    0 ,    0 ,
   0 ,  194 ,    0 ,    0 ,
   0 ,  195 ,    0 ,    0 ,
   0 ,  196 ,    0 ,    0 ,
   0 ,  197 ,    0 ,    0 ,
   0 ,  198 ,    0 ,    0 ,
   0 ,  199 ,    0 ,    0 ,
   0 ,  200 ,    0 ,    0 ,
   0 ,  201 ,    0 ,    0 ,
   0 ,  202 ,    0 ,    0 ,
   0 ,  203 ,    0 ,    0 ,
   0 ,  204 ,    0 ,    0 ,
   0 ,  205 ,    0 ,    0 ,
   0 ,  206 ,    0 ,    0 ,
   0 ,  207 ,    0 ,    0 ,
   0 ,  208 ,    0 ,    0 ,
   0 ,  209 ,    0 ,    0 ,
   0 ,  210 ,    0 ,    0 ,
   0 ,  211 ,    0 ,    0 ,
   0 ,  212 ,    0 ,    0 ,
   0 ,  213 ,    0 ,    0 ,
   0 ,  214 ,    0 ,    0 ,
   0 ,  215 ,    0 ,    0 ,
   0 ,  216 ,    0 ,    0 ,
   0 ,  217 ,    0 ,    0 ,
   0 ,  218 ,    0 ,    0 ,
   0 ,  219 ,    0 ,    0 ,
   0 ,  220 ,    0 ,    0 ,
   0 ,  221 ,    0 ,    0 ,
   0 ,  222 ,    0 ,    0 ,
   0 ,  223 ,    0 ,    0 ,
   0 ,  224 ,    0 ,    0 ,
   0 ,  225 ,    0 ,    0 ,
   0 ,  226 ,    0 ,    0 ,
   0 ,  227 ,    0 ,    0 ,
   0 ,  228 ,    0 ,    0 ,
   0 ,  229 ,    0 ,    0 ,
   0 ,  230 ,    0 ,    0 ,
   0 ,  231 ,    0 ,    0 ,
   0 ,  232 ,    0 ,    0 ,
   0 ,  233 ,    0 ,    0 ,
   0 ,  234 ,    0 ,    0 ,
   0 ,  235 ,    0 ,    0 ,
   0 ,  236 ,    0 ,    0 ,
   0 ,  237 ,    0 ,    0 ,
   0 ,  238 ,    0 ,    0 ,
   0 ,  239 ,    0 ,    0 ,
   0 ,  240 ,    0 ,    0 ,
   0 ,  241 ,    0 ,    0 ,
   0 ,  242 ,    0 ,    0 ,
   0 ,  243 ,    0 ,    0 ,
   0 ,  244 ,    0 ,    0 ,
   0 ,  245 ,    0 ,    0 ,
   0 ,  246 ,    0 ,    0 ,
   0 ,  247 ,    0 ,    0 ,
   0 ,  248 ,    0 ,    0 ,
   0 ,  249 ,    0 ,    0 ,
   0 ,  250 ,    0 ,    0 ,
   0 ,  251 ,    0 ,    0 ,
   0 ,  252 ,    0 ,    0 ,
   0 ,  253 ,    0 ,    0 ,
   0 ,  254 ,    0 ,    0 ,
   0 ,  254 ,    0 ,    0
};

const unsigned char HT300x3004level_open[1024]=
{
   0 ,    0 ,    0 ,    0 ,
   0 ,    0 ,    0 ,    0 ,
   0 ,    6 ,    0 ,    0 ,
   0 ,    9 ,    0 ,    0 ,
   0 ,   12 ,    0 ,    0 ,
   0 ,   15 ,    0 ,    0 ,
   0 ,   18 ,    0 ,    0 ,
   0 ,   21 ,    0 ,    0 ,
   0 ,   24 ,    0 ,    0 ,
   0 ,   27 ,    0 ,    0 ,
   0 ,   30 ,    0 ,    0 ,
   0 ,   33 ,    0 ,    0 ,
   0 ,   36 ,    0 ,    0 ,
   0 ,   39 ,    0 ,    0 ,
   0 ,   42 ,    0 ,    0 ,
   0 ,   45 ,    0 ,    0 ,
   0 ,   48 ,    0 ,    0 ,
   0 ,   51 ,    0 ,    0 ,
   0 ,   54 ,    0 ,    0 ,
   0 ,   57 ,    0 ,    0 ,
   0 ,   60 ,    0 ,    0 ,
   0 ,   63 ,    0 ,    0 ,
   0 ,   66 ,    0 ,    0 ,
   0 ,   69 ,    0 ,    0 ,
   0 ,   72 ,    0 ,    0 ,
   0 ,   75 ,    0 ,    0 ,
   0 ,   78 ,    0 ,    0 ,
   0 ,   81 ,    0 ,    0 ,
   0 ,   84 ,    0 ,    0 ,
   0 ,   87 ,    0 ,    0 ,
   0 ,   90 ,    0 ,    0 ,
   0 ,   93 ,    0 ,    0 ,
   0 ,   96 ,    0 ,    0 ,
   0 ,   99 ,    0 ,    0 ,
   0 ,  102 ,    0 ,    0 ,
   0 ,  105 ,    0 ,    0 ,
   0 ,  108 ,    0 ,    0 ,
   0 ,  111 ,    0 ,    0 ,
   0 ,  114 ,    0 ,    0 ,
   0 ,  117 ,    0 ,    0 ,
   0 ,  120 ,    0 ,    0 ,
   0 ,  123 ,    0 ,    0 ,
   0 ,  126 ,    0 ,    0 ,
   0 ,  129 ,    0 ,    0 ,
   0 ,  132 ,    0 ,    0 ,
   0 ,  135 ,    0 ,    0 ,
   0 ,  138 ,    0 ,    0 ,
   0 ,  141 ,    0 ,    0 ,
   0 ,  144 ,    0 ,    0 ,
   0 ,  147 ,    0 ,    0 ,
   0 ,  150 ,    0 ,    0 ,
   0 ,  153 ,    0 ,    0 ,
   0 ,  156 ,    0 ,    0 ,
   0 ,  159 ,    0 ,    0 ,
   0 ,  162 ,    0 ,    0 ,
   0 ,  165 ,    0 ,    0 ,
   0 ,  168 ,    0 ,    0 ,
   0 ,  171 ,    0 ,    0 ,
   0 ,  174 ,    0 ,    0 ,
   0 ,  177 ,    0 ,    0 ,
   0 ,  180 ,    0 ,    0 ,
   0 ,  183 ,    0 ,    0 ,
   0 ,  186 ,    0 ,    0 ,
   0 ,  189 ,    0 ,    0 ,
   0 ,  192 ,    0 ,    0 ,
   0 ,  195 ,    0 ,    0 ,
   0 ,  198 ,    0 ,    0 ,
   0 ,  201 ,    0 ,    0 ,
   0 ,  204 ,    0 ,    0 ,
   0 ,  207 ,    0 ,    0 ,
   0 ,  210 ,    0 ,    0 ,
   0 ,  213 ,    0 ,    0 ,
   0 ,  216 ,    0 ,    0 ,
   0 ,  219 ,    0 ,    0 ,
   0 ,  222 ,    0 ,    0 ,
   0 ,  225 ,    0 ,    0 ,
   0 ,  228 ,    0 ,    0 ,
   0 ,  231 ,    0 ,    0 ,
   0 ,  234 ,    0 ,    0 ,
   0 ,  237 ,    0 ,    0 ,
   0 ,  240 ,    0 ,    0 ,
   0 ,  243 ,    0 ,    0 ,
   0 ,  246 ,    0 ,    0 ,
   0 ,  249 ,    0 ,    0 ,
   0 ,  252 ,    0 ,    0 ,
   1 ,    0 ,    0 ,    0 ,
   1 ,    3 ,    0 ,    0 ,
   1 ,    6 ,    0 ,    0 ,
   1 ,    9 ,    0 ,    0 ,
   1 ,   12 ,    0 ,    0 ,
   1 ,   15 ,    0 ,    0 ,
   1 ,   18 ,    0 ,    0 ,
   1 ,   21 ,    0 ,    0 ,
   1 ,   24 ,    0 ,    0 ,
   1 ,   27 ,    0 ,    0 ,
   1 ,   30 ,    0 ,    0 ,
   1 ,   33 ,    0 ,    0 ,
   1 ,   36 ,    0 ,    0 ,
   1 ,   39 ,    0 ,    0 ,
   1 ,   42 ,    0 ,    0 ,
   1 ,   45 ,    0 ,    0 ,
   1 ,   48 ,    0 ,    0 ,
   1 ,   51 ,    0 ,    0 ,
   1 ,   54 ,    0 ,    0 ,
   1 ,   57 ,    0 ,    0 ,
   1 ,   60 ,    0 ,    0 ,
   1 ,   63 ,    0 ,    0 ,
   1 ,   66 ,    0 ,    0 ,
   1 ,   69 ,    0 ,    0 ,
   1 ,   72 ,    0 ,    0 ,
   1 ,   75 ,    0 ,    0 ,
   1 ,   78 ,    0 ,    0 ,
   1 ,   81 ,    0 ,    0 ,
   1 ,   84 ,    0 ,    0 ,
   1 ,   87 ,    0 ,    0 ,
   1 ,   90 ,    0 ,    0 ,
   1 ,   93 ,    0 ,    0 ,
   1 ,   96 ,    0 ,    0 ,
   1 ,   99 ,    0 ,    0 ,
   1 ,  102 ,    0 ,    0 ,
   1 ,  105 ,    0 ,    0 ,
   1 ,  108 ,    0 ,    0 ,
   1 ,  111 ,    0 ,    0 ,
   1 ,  114 ,    0 ,    0 ,
   1 ,  117 ,    0 ,    0 ,
   1 ,  120 ,    0 ,    0 ,
   1 ,  123 ,    0 ,    0 ,
   1 ,  126 ,    0 ,    0 ,
   1 ,  129 ,    0 ,    0 ,
   1 ,  132 ,    0 ,    0 ,
   1 ,  135 ,    0 ,    0 ,
   1 ,  138 ,    0 ,    0 ,
   1 ,  141 ,    0 ,    0 ,
   1 ,  144 ,    0 ,    0 ,
   1 ,  147 ,    0 ,    0 ,
   1 ,  150 ,    0 ,    0 ,
   1 ,  153 ,    0 ,    0 ,
   1 ,  156 ,    0 ,    0 ,
   1 ,  159 ,    0 ,    0 ,
   1 ,  162 ,    0 ,    0 ,
   1 ,  165 ,    0 ,    0 ,
   1 ,  168 ,    0 ,    0 ,
   1 ,  171 ,    0 ,    0 ,
   1 ,  174 ,    0 ,    0 ,
   1 ,  177 ,    0 ,    0 ,
   1 ,  180 ,    0 ,    0 ,
   1 ,  183 ,    0 ,    0 ,
   1 ,  186 ,    0 ,    0 ,
   1 ,  189 ,    0 ,    0 ,
   1 ,  192 ,    0 ,    0 ,
   1 ,  195 ,    0 ,    0 ,
   1 ,  198 ,    0 ,    0 ,
   1 ,  201 ,    0 ,    0 ,
   1 ,  204 ,    0 ,    0 ,
   1 ,  207 ,    0 ,    0 ,
   1 ,  210 ,    0 ,    0 ,
   1 ,  213 ,    0 ,    0 ,
   1 ,  216 ,    0 ,    0 ,
   1 ,  219 ,    0 ,    0 ,
   1 ,  222 ,    0 ,    0 ,
   1 ,  225 ,    0 ,    0 ,
   1 ,  228 ,    0 ,    0 ,
   1 ,  231 ,    0 ,    0 ,
   1 ,  234 ,    0 ,    0 ,
   1 ,  237 ,    0 ,    0 ,
   1 ,  240 ,    0 ,    0 ,
   1 ,  243 ,    0 ,    0 ,
   1 ,  246 ,    0 ,    0 ,
   1 ,  249 ,    0 ,    0 ,
   1 ,  252 ,    0 ,    0 ,
   2 ,    0 ,    0 ,    0 ,
   2 ,    3 ,    0 ,    0 ,
   2 ,    6 ,    0 ,    0 ,
   2 ,    9 ,    0 ,    0 ,
   2 ,   12 ,    0 ,    0 ,
   2 ,   15 ,    0 ,    0 ,
   2 ,   18 ,    0 ,    0 ,
   2 ,   21 ,    0 ,    0 ,
   2 ,   24 ,    0 ,    0 ,
   2 ,   27 ,    0 ,    0 ,
   2 ,   30 ,    0 ,    0 ,
   2 ,   33 ,    0 ,    0 ,
   2 ,   36 ,    0 ,    0 ,
   2 ,   39 ,    0 ,    0 ,
   2 ,   42 ,    0 ,    0 ,
   2 ,   45 ,    0 ,    0 ,
   2 ,   48 ,    0 ,    0 ,
   2 ,   51 ,    0 ,    0 ,
   2 ,   54 ,    0 ,    0 ,
   2 ,   57 ,    0 ,    0 ,
   2 ,   60 ,    0 ,    0 ,
   2 ,   63 ,    0 ,    0 ,
   2 ,   66 ,    0 ,    0 ,
   2 ,   69 ,    0 ,    0 ,
   2 ,   72 ,    0 ,    0 ,
   2 ,   75 ,    0 ,    0 ,
   2 ,   78 ,    0 ,    0 ,
   2 ,   81 ,    0 ,    0 ,
   2 ,   84 ,    0 ,    0 ,
   2 ,   87 ,    0 ,    0 ,
   2 ,   90 ,    0 ,    0 ,
   2 ,   93 ,    0 ,    0 ,
   2 ,   96 ,    0 ,    0 ,
   2 ,   99 ,    0 ,    0 ,
   2 ,  102 ,    0 ,    0 ,
   2 ,  105 ,    0 ,    0 ,
   2 ,  108 ,    0 ,    0 ,
   2 ,  111 ,    0 ,    0 ,
   2 ,  114 ,    0 ,    0 ,
   2 ,  117 ,    0 ,    0 ,
   2 ,  120 ,    0 ,    0 ,
   2 ,  123 ,    0 ,    0 ,
   2 ,  126 ,    0 ,    0 ,
   2 ,  129 ,    0 ,    0 ,
   2 ,  132 ,    0 ,    0 ,
   2 ,  135 ,    0 ,    0 ,
   2 ,  138 ,    0 ,    0 ,
   2 ,  141 ,    0 ,    0 ,
   2 ,  144 ,    0 ,    0 ,
   2 ,  147 ,    0 ,    0 ,
   2 ,  150 ,    0 ,    0 ,
   2 ,  153 ,    0 ,    0 ,
   2 ,  156 ,    0 ,    0 ,
   2 ,  159 ,    0 ,    0 ,
   2 ,  162 ,    0 ,    0 ,
   2 ,  165 ,    0 ,    0 ,
   2 ,  168 ,    0 ,    0 ,
   2 ,  171 ,    0 ,    0 ,
   2 ,  174 ,    0 ,    0 ,
   2 ,  177 ,    0 ,    0 ,
   2 ,  180 ,    0 ,    0 ,
   2 ,  183 ,    0 ,    0 ,
   2 ,  186 ,    0 ,    0 ,
   2 ,  189 ,    0 ,    0 ,
   2 ,  192 ,    0 ,    0 ,
   2 ,  195 ,    0 ,    0 ,
   2 ,  198 ,    0 ,    0 ,
   2 ,  201 ,    0 ,    0 ,
   2 ,  204 ,    0 ,    0 ,
   2 ,  207 ,    0 ,    0 ,
   2 ,  210 ,    0 ,    0 ,
   2 ,  213 ,    0 ,    0 ,
   2 ,  216 ,    0 ,    0 ,
   2 ,  219 ,    0 ,    0 ,
   2 ,  222 ,    0 ,    0 ,
   2 ,  225 ,    0 ,    0 ,
   2 ,  228 ,    0 ,    0 ,
   2 ,  231 ,    0 ,    0 ,
   2 ,  234 ,    0 ,    0 ,
   2 ,  237 ,    0 ,    0 ,
   2 ,  240 ,    0 ,    0 ,
   2 ,  243 ,    0 ,    0 ,
   2 ,  246 ,    0 ,    0 ,
   2 ,  249 ,    0 ,    0 ,
   2 ,  252 ,    0 ,    0 ,
   2 ,  255 ,    0 ,    0
};

const unsigned char HT600x6004level895_open[1024]=
{
   0 ,    0 ,    0 ,    0 ,
   0 ,    0 ,    0 ,    0 ,
   0 ,    3 ,    0 ,    0 ,
   0 ,    3 ,    0 ,    0 ,
   0 ,    4 ,    0 ,    0 ,
   0 ,    4 ,    0 ,    0 ,
   0 ,    4 ,    0 ,    0 ,
   0 ,    4 ,    0 ,    0 ,
   0 ,    6 ,    0 ,    0 ,
   0 ,    6 ,    0 ,    0 ,
   0 ,    7 ,    0 ,    0 ,
   0 ,    7 ,    0 ,    0 ,
   0 ,    9 ,    0 ,    0 ,
   0 ,    9 ,    0 ,    0 ,
   0 ,   11 ,    0 ,    0 ,
   0 ,   11 ,    0 ,    0 ,
   0 ,   12 ,    0 ,    0 ,
   0 ,   12 ,    0 ,    0 ,
   0 ,   14 ,    0 ,    0 ,
   0 ,   14 ,    0 ,    0 ,
   0 ,   15 ,    0 ,    0 ,
   0 ,   15 ,    0 ,    0 ,
   0 ,   17 ,    0 ,    0 ,
   0 ,   17 ,    0 ,    0 ,
   0 ,   19 ,    0 ,    0 ,
   0 ,   19 ,    0 ,    0 ,
   0 ,   20 ,    0 ,    0 ,
   0 ,   20 ,    0 ,    0 ,
   0 ,   22 ,    0 ,    0 ,
   0 ,   22 ,    0 ,    0 ,
   0 ,   23 ,    0 ,    0 ,
   0 ,   23 ,    0 ,    0 ,
   0 ,   25 ,    0 ,    0 ,
   0 ,   25 ,    0 ,    0 ,
   0 ,   27 ,    0 ,    0 ,
   0 ,   27 ,    0 ,    0 ,
   0 ,   28 ,    0 ,    0 ,
   0 ,   28 ,    0 ,    0 ,
   0 ,   30 ,    0 ,    0 ,
   0 ,   30 ,    0 ,    0 ,
   0 ,   31 ,    0 ,    0 ,
   0 ,   31 ,    0 ,    0 ,
   0 ,   33 ,    0 ,    0 ,
   0 ,   33 ,    0 ,    0 ,
   0 ,   35 ,    0 ,    0 ,
   0 ,   35 ,    0 ,    0 ,
   0 ,   36 ,    0 ,    0 ,
   0 ,   36 ,    0 ,    0 ,
   0 ,   38 ,    0 ,    0 ,
   0 ,   38 ,    0 ,    0 ,
   0 ,   39 ,    0 ,    0 ,
   0 ,   39 ,    0 ,    0 ,
   0 ,   41 ,    0 ,    0 ,
   0 ,   41 ,    0 ,    0 ,
   0 ,   43 ,    0 ,    0 ,
   0 ,   44 ,    0 ,    0 ,
   0 ,   46 ,    0 ,    0 ,
   0 ,   47 ,    0 ,    0 ,
   0 ,   49 ,    0 ,    0 ,
   0 ,   51 ,    0 ,    0 ,
   0 ,   52 ,    0 ,    0 ,
   0 ,   54 ,    0 ,    0 ,
   0 ,   55 ,    0 ,    0 ,
   0 ,   57 ,    0 ,    0 ,
   0 ,   58 ,    0 ,    0 ,
   0 ,   60 ,    0 ,    0 ,
   0 ,   62 ,    0 ,    0 ,
   0 ,   63 ,    0 ,    0 ,
   0 ,   65 ,    0 ,    0 ,
   0 ,   66 ,    0 ,    0 ,
   0 ,   68 ,    0 ,    0 ,
   0 ,   70 ,    0 ,    0 ,
   0 ,   71 ,    0 ,    0 ,
   0 ,   73 ,    0 ,    0 ,
   0 ,   74 ,    0 ,    0 ,
   0 ,   78 ,    0 ,    0 ,
   0 ,   79 ,    0 ,    0 ,
   0 ,   82 ,    0 ,    0 ,
   0 ,   84 ,    0 ,    0 ,
   0 ,   86 ,    0 ,    0 ,
   0 ,   89 ,    0 ,    0 ,
   0 ,   90 ,    0 ,    0 ,
   0 ,   92 ,    0 ,    0 ,
   0 ,   95 ,    0 ,    0 ,
   0 ,   97 ,    0 ,    0 ,
   0 ,   98 ,    0 ,    0 ,
   0 ,  102 ,    0 ,    0 ,
   0 ,  103 ,    0 ,    0 ,
   0 ,  105 ,    0 ,    0 ,
   0 ,  108 ,    0 ,    0 ,
   0 ,  109 ,    0 ,    0 ,
   0 ,  111 ,    0 ,    0 ,
   0 ,  114 ,    0 ,    0 ,
   0 ,  116 ,    0 ,    0 ,
   0 ,  117 ,    0 ,    0 ,
   0 ,  121 ,    0 ,    0 ,
   0 ,  122 ,    0 ,    0 ,
   0 ,  124 ,    0 ,    0 ,
   0 ,  127 ,    0 ,    0 ,
   0 ,  129 ,    0 ,    0 ,
   0 ,  130 ,    0 ,    0 ,
   0 ,  133 ,    0 ,    0 ,
   0 ,  135 ,    0 ,    0 ,
   0 ,  137 ,    0 ,    0 ,
   0 ,  140 ,    0 ,    0 ,
   0 ,  141 ,    0 ,    0 ,
   0 ,  143 ,    0 ,    0 ,
   0 ,  146 ,    0 ,    0 ,
   0 ,  148 ,    0 ,    0 ,
   0 ,  149 ,    0 ,    0 ,
   0 ,  153 ,    0 ,    0 ,
   0 ,  154 ,    0 ,    0 ,
   0 ,  156 ,    0 ,    0 ,
   0 ,  159 ,    0 ,    0 ,
   0 ,  160 ,    0 ,    0 ,
   0 ,  162 ,    0 ,    0 ,
   0 ,  165 ,    0 ,    0 ,
   0 ,  167 ,    0 ,    0 ,
   0 ,  168 ,    0 ,    0 ,
   0 ,  172 ,    0 ,    0 ,
   0 ,  173 ,    0 ,    0 ,
   0 ,  175 ,    0 ,    0 ,
   0 ,  178 ,    0 ,    0 ,
   0 ,  180 ,    0 ,    0 ,
   0 ,  181 ,    0 ,    0 ,
   0 ,  184 ,    0 ,    0 ,
   0 ,  186 ,    0 ,    0 ,
   0 ,  188 ,    0 ,    0 ,
   0 ,  191 ,    0 ,    0 ,
   0 ,  192 ,    0 ,    0 ,
   0 ,  194 ,    0 ,    0 ,
   0 ,  197 ,    0 ,    0 ,
   0 ,  199 ,    0 ,    0 ,
   0 ,  200 ,    0 ,    0 ,
   0 ,  204 ,    0 ,    0 ,
   0 ,  205 ,    0 ,    0 ,
   0 ,  207 ,    0 ,    0 ,
   0 ,  210 ,    0 ,    0 ,
   0 ,  211 ,    0 ,    0 ,
   0 ,  213 ,    0 ,    0 ,
   0 ,  216 ,    0 ,    0 ,
   0 ,  218 ,    0 ,    0 ,
   0 ,  219 ,    0 ,    0 ,
   0 ,  223 ,    0 ,    0 ,
   0 ,  224 ,    0 ,    0 ,
   0 ,  226 ,    0 ,    0 ,
   0 ,  229 ,    0 ,    0 ,
   0 ,  231 ,    0 ,    0 ,
   0 ,  232 ,    0 ,    0 ,
   0 ,  235 ,    0 ,    0 ,
   0 ,  237 ,    0 ,    0 ,
   0 ,  239 ,    0 ,    0 ,
   0 ,  242 ,    0 ,    0 ,
   0 ,  243 ,    0 ,    0 ,
   0 ,  245 ,    0 ,    0 ,
   0 ,  248 ,    0 ,    0 ,
   0 ,  250 ,    0 ,    0 ,
   0 ,  251 ,    0 ,    0 ,
   0 ,  253 ,    0 ,    0 ,
   0 ,  255 ,    0 ,    0 ,
   1 ,    0 ,    0 ,    0 ,
   1 ,    3 ,    0 ,    0 ,
   1 ,    6 ,    0 ,    0 ,
   1 ,    9 ,    0 ,    0 ,
   1 ,   12 ,    0 ,    0 ,
   1 ,   15 ,    0 ,    0 ,
   1 ,   19 ,    0 ,    0 ,
   1 ,   22 ,    0 ,    0 ,
   1 ,   25 ,    0 ,    0 ,
   1 ,   28 ,    0 ,    0 ,
   1 ,   31 ,    0 ,    0 ,
   1 ,   35 ,    0 ,    0 ,
   1 ,   38 ,    0 ,    0 ,
   1 ,   41 ,    0 ,    0 ,
   1 ,   44 ,    0 ,    0 ,
   1 ,   47 ,    0 ,    0 ,
   1 ,   51 ,    0 ,    0 ,
   1 ,   54 ,    0 ,    0 ,
   1 ,   57 ,    0 ,    0 ,
   1 ,   60 ,    0 ,    0 ,
   1 ,   63 ,    0 ,    0 ,
   1 ,   66 ,    0 ,    0 ,
   1 ,   70 ,    0 ,    0 ,
   1 ,   73 ,    0 ,    0 ,
   1 ,   76 ,    0 ,    0 ,
   1 ,   79 ,    0 ,    0 ,
   1 ,   82 ,    0 ,    0 ,
   1 ,   86 ,    0 ,    0 ,
   1 ,   89 ,    0 ,    0 ,
   1 ,   92 ,    0 ,    0 ,
   1 ,   95 ,    0 ,    0 ,
   1 ,   98 ,    0 ,    0 ,
   1 ,  102 ,    0 ,    0 ,
   1 ,  105 ,    0 ,    0 ,
   1 ,  108 ,    0 ,    0 ,
   1 ,  111 ,    0 ,    0 ,
   1 ,  114 ,    0 ,    0 ,
   1 ,  117 ,    0 ,    0 ,
   1 ,  121 ,    0 ,    0 ,
   1 ,  124 ,    0 ,    0 ,
   1 ,  127 ,    0 ,    0 ,
   1 ,  130 ,    0 ,    0 ,
   1 ,  133 ,    0 ,    0 ,
   1 ,  137 ,    0 ,    0 ,
   1 ,  140 ,    0 ,    0 ,
   1 ,  143 ,    0 ,    0 ,
   1 ,  146 ,    0 ,    0 ,
   1 ,  149 ,    0 ,    0 ,
   1 ,  153 ,    0 ,    0 ,
   1 ,  156 ,    0 ,    0 ,
   1 ,  159 ,    0 ,    0 ,
   1 ,  162 ,    0 ,    0 ,
   1 ,  165 ,    0 ,    0 ,
   1 ,  168 ,    0 ,    0 ,
   1 ,  172 ,    0 ,    0 ,
   1 ,  175 ,    0 ,    0 ,
   1 ,  178 ,    0 ,    0 ,
   1 ,  181 ,    0 ,    0 ,
   1 ,  184 ,    0 ,    0 ,
   1 ,  188 ,    0 ,    0 ,
   1 ,  191 ,    0 ,    0 ,
   1 ,  194 ,    0 ,    0 ,
   1 ,  197 ,    0 ,    0 ,
   1 ,  200 ,    0 ,    0 ,
   1 ,  204 ,    0 ,    0 ,
   1 ,  207 ,    0 ,    0 ,
   1 ,  210 ,    0 ,    0 ,
   1 ,  213 ,    0 ,    0 ,
   1 ,  216 ,    0 ,    0 ,
   1 ,  219 ,    0 ,    0 ,
   1 ,  223 ,    0 ,    0 ,
   1 ,  226 ,    0 ,    0 ,
   1 ,  229 ,    0 ,    0 ,
   1 ,  232 ,    0 ,    0 ,
   1 ,  235 ,    0 ,    0 ,
   1 ,  239 ,    0 ,    0 ,
   1 ,  242 ,    0 ,    0 ,
   1 ,  245 ,    0 ,    0 ,
   1 ,  248 ,    0 ,    0 ,
   1 ,  251 ,    0 ,    0 ,
   2 ,    0 ,    0 ,    0 ,
   2 ,   15 ,    0 ,    0 ,
   2 ,   31 ,    0 ,    0 ,
   2 ,   47 ,    0 ,    0 ,
   2 ,   63 ,    0 ,    0 ,
   2 ,   79 ,    0 ,    0 ,
   2 ,   95 ,    0 ,    0 ,
   2 ,  111 ,    0 ,    0 ,
   2 ,  127 ,    0 ,    0 ,
   2 ,  143 ,    0 ,    0 ,
   2 ,  159 ,    0 ,    0 ,
   2 ,  175 ,    0 ,    0 ,
   2 ,  191 ,    0 ,    0 ,
   2 ,  207 ,    0 ,    0 ,
   2 ,  223 ,    0 ,    0 ,
   2 ,  239 ,    0 ,    0
};

const unsigned char HT600x6004level970_open[1024]=

{
0,  0,  255,    0,
0,  1,  255,    0,
0,  3,  255,    0,
0,  5,  255,    0,
0,  7,  255,    0,
0,  9,  255,    0,
0,  11, 255,    0,
0,  13, 255,    0,
0,  15, 255,    0,
0,  17, 255,    0,
0,  19, 255,    0,
0,  21, 255,    0,
0,  23, 255,    0,
0,  25, 255,    0,
0,  27, 255,    0,
0,  29, 255,    0,
0,  31, 255,    0,
0,  33, 255,    0,
0,  35, 255,    0,
0,  37, 255,    0,
0,  39, 255,    0,
0,  41, 255,    0,
0,  43, 255,    0,
0,  45, 255,    0,
0,  47, 255,    0,
0,  49, 255,    0,
0,  51, 255,    0,
0,  53, 255,    0,
0,  55, 255,    0,
0,  57, 255,    0,
0,  59, 255,    0,
0,  61, 255,    0,
0,  63, 255,    0,
0,  65, 255,    0,
0,  67, 255,    0,
0,  69, 255,    0,
0,  71, 255,    0,
0,  73, 255,    0,
0,  75, 255,    0,
0,  77, 255,    0,
0,  79, 255,    0,
0,  81, 255,    0,
0,  83, 255,    0,
0,  85, 255,    0,
0,  87, 255,    0,
0,  89, 255,    0,
0,  91, 255,    0,
0,  93, 255,    0,
0,  95, 255,    0,
0,  97, 255,    0,
0,  99, 255,    0,
0,  101,    255,    0,
0,  103,    255,    0,
0,  105,    255,    0,
0,  107,    255,    0,
0,  109,    255,    0,
0,  111,    255,    0,
0,  113,    255,    0,
0,  115,    255,    0,
0,  117,    255,    0,
0,  119,    255,    0,
0,  121,    255,    0,
0,  123,    255,    0,
0,  125,    255,    0,
0,  127,    255,    0,
0,  129,    255,    0,
0,  131,    255,    0,
0,  133,    255,    0,
0,  135,    255,    0,
0,  137,    255,    0,
0,  139,    255,    0,
0,  141,    255,    0,
0,  143,    255,    0,
0,  145,    255,    0,
0,  147,    255,    0,
0,  149,    255,    0,
0,  151,    255,    0,
0,  153,    255,    0,
0,  155,    255,    0,
0,  157,    255,    0,
0,  159,    255,    0,
0,  161,    255,    0,
0,  163,    255,    0,
0,  165,    255,    0,
0,  167,    255,    0,
0,  169,    255,    0,
0,  171,    255,    0,
0,  173,    255,    0,
0,  175,    255,    0,
0,  177,    255,    0,
0,  179,    255,    0,
0,  181,    255,    0,
0,  183,    255,    0,
0,  185,    255,    0,
0,  187,    255,    0,
0,  189,    255,    0,
0,  191,    255,    0,
0,  193,    255,    0,
0,  195,    255,    0,
0,  197,    255,    0,
0,  199,    255,    0,
0,  201,    255,    0,
0,  203,    255,    0,
0,  205,    255,    0,
0,  207,    255,    0,
0,  209,    255,    0,
0,  211,    255,    0,
0,  213,    255,    0,
0,  215,    255,    0,
0,  217,    255,    0,
0,  219,    255,    0,
0,  221,    255,    0,
0,  223,    255,    0,
0,  225,    255,    0,
0,  227,    255,    0,
0,  229,    255,    0,
0,  231,    255,    0,
0,  233,    255,    0,
0,  235,    255,    0,
0,  237,    255,    0,
0,  239,    255,    0,
0,  241,    255,    0,
0,  243,    255,    0,
0,  245,    255,    0,
0,  247,    255,    0,
0,  249,    255,    0,
0,  251,    255,    0,
0,  253,    255,    0,
0,  255,    255,    0,
1,  3,  255,    0,
1,  7,  255,    0,
1,  11, 255,    0,
1,  15, 255,    0,
1,  19, 255,    0,
1,  23, 255,    0,
1,  27, 255,    0,
1,  31, 255,    0,
1,  35, 255,    0,
1,  39, 255,    0,
1,  43, 255,    0,
1,  47, 255,    0,
1,  51, 255,    0,
1,  55, 255,    0,
1,  59, 255,    0,
1,  63, 255,    0,
1,  67, 255,    0,
1,  71, 255,    0,
1,  75, 255,    0,
1,  79, 255,    0,
1,  83, 255,    0,
1,  87, 255,    0,
1,  91, 255,    0,
1,  95, 255,    0,
1,  99, 255,    0,
1,  103,    255,    0,
1,  107,    255,    0,
1,  111,    255,    0,
1,  115,    255,    0,
1,  119,    255,    0,
1,  123,    255,    0,
1,  127,    255,    0,
1,  131,    255,    0,
1,  135,    255,    0,
1,  139,    255,    0,
1,  143,    255,    0,
1,  147,    255,    0,
1,  151,    255,    0,
1,  155,    255,    0,
1,  159,    255,    0,
1,  163,    255,    0,
1,  167,    255,    0,
1,  171,    255,    0,
1,  175,    255,    0,
1,  179,    255,    0,
1,  183,    255,    0,
1,  187,    255,    0,
1,  191,    255,    0,
1,  195,    255,    0,
1,  199,    255,    0,
1,  203,    255,    0,
1,  207,    255,    0,
1,  211,    255,    0,
1,  215,    255,    0,
1,  219,    255,    0,
1,  223,    255,    0,
1,  227,    255,    0,
1,  231,    255,    0,
1,  235,    255,    0,
1,  239,    255,    0,
1,  243,    255,    0,
1,  247,    255,    0,
1,  251,    255,    0,
1,  255,    255,    0,
2,  4,  255,    0,
2,  8,  255,    0,
2,  12, 255,    0,
2,  16, 255,    0,
2,  20, 255,    0,
2,  24, 255,    0,
2,  28, 255,    0,
2,  32, 255,    0,
2,  36, 255,    0,
2,  40, 255,    0,
2,  44, 255,    0,
2,  48, 255,    0,
2,  52, 255,    0,
2,  56, 255,    0,
2,  60, 255,    0,
2,  64, 255,    0,
2,  68, 255,    0,
2,  72, 255,    0,
2,  76, 255,    0,
2,  80, 255,    0,
2,  85, 255,    0,
2,  89, 255,    0,
2,  93, 255,    0,
2,  97, 255,    0,
2,  101,    255,    0,
2,  105,    255,    0,
2,  109,    255,    0,
2,  113,    255,    0,
2,  117,    255,    0,
2,  121,    255,    0,
2,  125,    255,    0,
2,  129,    255,    0,
2,  133,    255,    0,
2,  137,    255,    0,
2,  141,    255,    0,
2,  145,    255,    0,
2,  149,    255,    0,
2,  153,    255,    0,
2,  157,    255,    0,
2,  161,    255,    0,
2,  165,    255,    0,
2,  170,    255,    0,
2,  174,    255,    0,
2,  178,    255,    0,
2,  182,    255,    0,
2,  186,    255,    0,
2,  190,    255,    0,
2,  194,    255,    0,
2,  198,    255,    0,
2,  202,    255,    0,
2,  206,    255,    0,
2,  210,    255,    0,
2,  214,    255,    0,
2,  218,    255,    0,
2,  222,    255,    0,
2,  226,    255,    0,
2,  230,    255,    0,
2,  234,    255,    0,
2,  238,    255,    0,
2,  242,    255,    0,
2,  246,    255,    0,
2,  250,    255,    0,
2,  255,    255,    0
};

#ifdef APDK_AUTODUPLEX

 // 2001.07.09 mrb: Added for photo glossy mode of DJ970
 const unsigned char HT1200x1200x1_PhotoPres970_open[1024]=
 {
    0 ,   0 ,   0 ,   0 ,
    0 ,   0 ,   0 ,   0 ,
    0 ,   1 ,   0 ,   0 ,
    0 ,   1 ,   0 ,   0 ,
    0 ,   2 ,   0 ,   0 ,
    0 ,   2 ,   0 ,   0 ,
    0 ,   3 ,   0 ,   0 ,
    0 ,   3 ,   0 ,   0 ,
    0 ,   4 ,   0 ,   0 ,
    0 ,   4 ,   0 ,   0 ,
    0 ,   5 ,   0 ,   0 ,
    0 ,   5 ,   0 ,   0 ,
    0 ,   6 ,   0 ,   0 ,
    0 ,   6 ,   0 ,   0 ,
    0 ,   7 ,   0 ,   0 ,
    0 ,   7 ,   0 ,   0 ,
    0 ,   8 ,   0 ,   0 ,
    0 ,   8 ,   0 ,   0 ,
    0 ,   9 ,   0 ,   0 ,
    0 ,   9 ,   0 ,   0 ,
    0 ,  10 ,   0 ,   0 ,
    0 ,  10 ,   0 ,   0 ,
    0 ,  11 ,   0 ,   0 ,
    0 ,  11 ,   0 ,   0 ,
    0 ,  12 ,   0 ,   0 ,
    0 ,  12 ,   0 ,   0 ,
    0 ,  13 ,   0 ,   0 ,
    0 ,  13 ,   0 ,   0 ,
    0 ,  14 ,   0 ,   0 ,
    0 ,  14 ,   0 ,   0 ,
    0 ,  15 ,   0 ,   0 ,
    0 ,  15 ,   0 ,   0 ,
    0 ,  16 ,   0 ,   0 ,
    0 ,  16 ,   0 ,   0 ,
    0 ,  17 ,   0 ,   0 ,
    0 ,  17 ,   0 ,   0 ,
    0 ,  18 ,   0 ,   0 ,
    0 ,  18 ,   0 ,   0 ,
    0 ,  19 ,   0 ,   0 ,
    0 ,  19 ,   0 ,   0 ,
    0 ,  20 ,   0 ,   0 ,
    0 ,  20 ,   0 ,   0 ,
    0 ,  21 ,   0 ,   0 ,
    0 ,  21 ,   0 ,   0 ,
    0 ,  22 ,   0 ,   0 ,
    0 ,  22 ,   0 ,   0 ,
    0 ,  23 ,   0 ,   0 ,
    0 ,  23 ,   0 ,   0 ,
    0 ,  24 ,   0 ,   0 ,
    0 ,  24 ,   0 ,   0 ,
    0 ,  25 ,   0 ,   0 ,
    0 ,  25 ,   0 ,   0 ,
    0 ,  26 ,   0 ,   0 ,
    0 ,  26 ,   0 ,   0 ,
    0 ,  27 ,   0 ,   0 ,
    0 ,  27 ,   0 ,   0 ,
    0 ,  28 ,   0 ,   0 ,
    0 ,  28 ,   0 ,   0 ,
    0 ,  29 ,   0 ,   0 ,
    0 ,  29 ,   0 ,   0 ,
    0 ,  30 ,   0 ,   0 ,
    0 ,  30 ,   0 ,   0 ,
    0 ,  31 ,   0 ,   0 ,
    0 ,  31 ,   0 ,   0 ,
    0 ,  32 ,   0 ,   0 ,
    0 ,  32 ,   0 ,   0 ,
    0 ,  33 ,   0 ,   0 ,
    0 ,  33 ,   0 ,   0 ,
    0 ,  34 ,   0 ,   0 ,
    0 ,  34 ,   0 ,   0 ,
    0 ,  35 ,   0 ,   0 ,
    0 ,  35 ,   0 ,   0 ,
    0 ,  36 ,   0 ,   0 ,
    0 ,  36 ,   0 ,   0 ,
    0 ,  37 ,   0 ,   0 ,
    0 ,  37 ,   0 ,   0 ,
    0 ,  38 ,   0 ,   0 ,
    0 ,  38 ,   0 ,   0 ,
    0 ,  39 ,   0 ,   0 ,
    0 ,  39 ,   0 ,   0 ,
    0 ,  40 ,   0 ,   0 ,
    0 ,  40 ,   0 ,   0 ,
    0 ,  41 ,   0 ,   0 ,
    0 ,  41 ,   0 ,   0 ,
    0 ,  42 ,   0 ,   0 ,
    0 ,  42 ,   0 ,   0 ,
    0 ,  43 ,   0 ,   0 ,
    0 ,  43 ,   0 ,   0 ,
    0 ,  44 ,   0 ,   0 ,
    0 ,  44 ,   0 ,   0 ,
    0 ,  45 ,   0 ,   0 ,
    0 ,  45 ,   0 ,   0 ,
    0 ,  46 ,   0 ,   0 ,
    0 ,  46 ,   0 ,   0 ,
    0 ,  47 ,   0 ,   0 ,
    0 ,  47 ,   0 ,   0 ,
    0 ,  48 ,   0 ,   0 ,
    0 ,  48 ,   0 ,   0 ,
    0 ,  49 ,   0 ,   0 ,
    0 ,  49 ,   0 ,   0 ,
    0 ,  50 ,   0 ,   0 ,
    0 ,  50 ,   0 ,   0 ,
    0 ,  51 ,   0 ,   0 ,
    0 ,  51 ,   0 ,   0 ,
    0 ,  52 ,   0 ,   0 ,
    0 ,  52 ,   0 ,   0 ,
    0 ,  53 ,   0 ,   0 ,
    0 ,  53 ,   0 ,   0 ,
    0 ,  54 ,   0 ,   0 ,
    0 ,  54 ,   0 ,   0 ,
    0 ,  55 ,   0 ,   0 ,
    0 ,  55 ,   0 ,   0 ,
    0 ,  56 ,   0 ,   0 ,
    0 ,  56 ,   0 ,   0 ,
    0 ,  57 ,   0 ,   0 ,
    0 ,  57 ,   0 ,   0 ,
    0 ,  58 ,   0 ,   0 ,
    0 ,  58 ,   0 ,   0 ,
    0 ,  59 ,   0 ,   0 ,
    0 ,  59 ,   0 ,   0 ,
    0 ,  60 ,   0 ,   0 ,
    0 ,  60 ,   0 ,   0 ,
    0 ,  61 ,   0 ,   0 ,
    0 ,  61 ,   0 ,   0 ,
    0 ,  62 ,   0 ,   0 ,
    0 ,  62 ,   0 ,   0 ,
    0 ,  63 ,   0 ,   0 ,
    0 ,  63 ,   0 ,   0 ,
    0 ,  64 ,   0 ,   0 ,
    0 ,  64 ,   0 ,   0 ,
    0 ,  65 ,   0 ,   0 ,
    0 ,  65 ,   0 ,   0 ,
    0 ,  66 ,   0 ,   0 ,
    0 ,  66 ,   0 ,   0 ,
    0 ,  67 ,   0 ,   0 ,
    0 ,  67 ,   0 ,   0 ,
    0 ,  68 ,   0 ,   0 ,
    0 ,  68 ,   0 ,   0 ,
    0 ,  69 ,   0 ,   0 ,
    0 ,  69 ,   0 ,   0 ,
    0 ,  70 ,   0 ,   0 ,
    0 ,  70 ,   0 ,   0 ,
    0 ,  71 ,   0 ,   0 ,
    0 ,  71 ,   0 ,   0 ,
    0 ,  72 ,   0 ,   0 ,
    0 ,  72 ,   0 ,   0 ,
    0 ,  73 ,   0 ,   0 ,
    0 ,  73 ,   0 ,   0 ,
    0 ,  74 ,   0 ,   0 ,
    0 ,  74 ,   0 ,   0 ,
    0 ,  75 ,   0 ,   0 ,
    0 ,  75 ,   0 ,   0 ,
    0 ,  76 ,   0 ,   0 ,
    0 ,  76 ,   0 ,   0 ,
    0 ,  77 ,   0 ,   0 ,
    0 ,  77 ,   0 ,   0 ,
    0 ,  78 ,   0 ,   0 ,
    0 ,  78 ,   0 ,   0 ,
    0 ,  79 ,   0 ,   0 ,
    0 ,  79 ,   0 ,   0 ,
    0 ,  80 ,   0 ,   0 ,
    0 ,  80 ,   0 ,   0 ,
    0 ,  81 ,   0 ,   0 ,
    0 ,  81 ,   0 ,   0 ,
    0 ,  82 ,   0 ,   0 ,
    0 ,  82 ,   0 ,   0 ,
    0 ,  83 ,   0 ,   0 ,
    0 ,  83 ,   0 ,   0 ,
    0 ,  84 ,   0 ,   0 ,
    0 ,  84 ,   0 ,   0 ,
    0 ,  85 ,   0 ,   0 ,
    0 ,  85 ,   0 ,   0 ,
    0 ,  86 ,   0 ,   0 ,
    0 ,  86 ,   0 ,   0 ,
    0 ,  87 ,   0 ,   0 ,
    0 ,  87 ,   0 ,   0 ,
    0 ,  88 ,   0 ,   0 ,
    0 ,  88 ,   0 ,   0 ,
    0 ,  89 ,   0 ,   0 ,
    0 ,  89 ,   0 ,   0 ,
    0 ,  90 ,   0 ,   0 ,
    0 ,  90 ,   0 ,   0 ,
    0 ,  91 ,   0 ,   0 ,
    0 ,  91 ,   0 ,   0 ,
    0 ,  92 ,   0 ,   0 ,
    0 ,  92 ,   0 ,   0 ,
    0 ,  93 ,   0 ,   0 ,
    0 ,  93 ,   0 ,   0 ,
    0 ,  94 ,   0 ,   0 ,
    0 ,  94 ,   0 ,   0 ,
    0 ,  95 ,   0 ,   0 ,
    0 ,  95 ,   0 ,   0 ,
    0 ,  96 ,   0 ,   0 ,
    0 ,  96 ,   0 ,   0 ,
    0 ,  97 ,   0 ,   0 ,
    0 ,  97 ,   0 ,   0 ,
    0 ,  98 ,   0 ,   0 ,
    0 ,  98 ,   0 ,   0 ,
    0 ,  99 ,   0 ,   0 ,
    0 ,  99 ,   0 ,   0 ,
    0 , 100 ,   0 ,   0 ,
    0 , 100 ,   0 ,   0 ,
    0 , 101 ,   0 ,   0 ,
    0 , 101 ,   0 ,   0 ,
    0 , 102 ,   0 ,   0 ,
    0 , 102 ,   0 ,   0 ,
    0 , 103 ,   0 ,   0 ,
    0 , 103 ,   0 ,   0 ,
    0 , 104 ,   0 ,   0 ,
    0 , 104 ,   0 ,   0 ,
    0 , 105 ,   0 ,   0 ,
    0 , 105 ,   0 ,   0 ,
    0 , 106 ,   0 ,   0 ,
    0 , 106 ,   0 ,   0 ,
    0 , 107 ,   0 ,   0 ,
    0 , 107 ,   0 ,   0 ,
    0 , 108 ,   0 ,   0 ,
    0 , 108 ,   0 ,   0 ,
    0 , 109 ,   0 ,   0 ,
    0 , 109 ,   0 ,   0 ,
    0 , 110 ,   0 ,   0 ,
    0 , 110 ,   0 ,   0 ,
    0 , 111 ,   0 ,   0 ,
    0 , 111 ,   0 ,   0 ,
    0 , 112 ,   0 ,   0 ,
    0 , 112 ,   0 ,   0 ,
    0 , 113 ,   0 ,   0 ,
    0 , 113 ,   0 ,   0 ,
    0 , 114 ,   0 ,   0 ,
    0 , 114 ,   0 ,   0 ,
    0 , 115 ,   0 ,   0 ,
    0 , 115 ,   0 ,   0 ,
    0 , 116 ,   0 ,   0 ,
    0 , 116 ,   0 ,   0 ,
    0 , 117 ,   0 ,   0 ,
    0 , 117 ,   0 ,   0 ,
    0 , 118 ,   0 ,   0 ,
    0 , 118 ,   0 ,   0 ,
    0 , 119 ,   0 ,   0 ,
    0 , 119 ,   0 ,   0 ,
    0 , 120 ,   0 ,   0 ,
    0 , 120 ,   0 ,   0 ,
    0 , 121 ,   0 ,   0 ,
    0 , 121 ,   0 ,   0 ,
    0 , 122 ,   0 ,   0 ,
    0 , 122 ,   0 ,   0 ,
    0 , 123 ,   0 ,   0 ,
    0 , 123 ,   0 ,   0 ,
    0 , 124 ,   0 ,   0 ,
    0 , 124 ,   0 ,   0 ,
    0 , 125 ,   0 ,   0 ,
    0 , 125 ,   0 ,   0 ,
    0 , 126 ,   0 ,   0 ,
    0 , 126 ,   0 ,   0 ,
    0 , 127 ,   0 ,   0 ,
    0 , 127 ,   0 ,   0
 };
 
 // 2001.07.09 mrb: Added for presentation mode of DJ970
 const unsigned char HT600x600x4_Pres970_open[1024]=
 {
    0 ,   0 , 255 ,   0 ,
    0 ,   0 , 255 ,   0 ,
    0 ,   2 , 255 ,   0 ,
    0 ,   3 , 255 ,   0 ,
    0 ,   4 , 255 ,   0 ,
    0 ,   5 , 255 ,   0 ,
    0 ,   6 , 255 ,   0 ,
    0 ,   7 , 255 ,   0 ,
    0 ,   8 , 255 ,   0 ,
    0 ,   9 , 255 ,   0 ,
    0 ,  10 , 255 ,   0 ,
    0 ,  11 , 255 ,   0 ,
    0 ,  12 , 255 ,   0 ,
    0 ,  13 , 255 ,   0 ,
    0 ,  14 , 255 ,   0 ,
    0 ,  15 , 255 ,   0 ,
    0 ,  16 , 255 ,   0 ,
    0 ,  17 , 255 ,   0 ,
    0 ,  18 , 255 ,   0 ,
    0 ,  19 , 255 ,   0 ,
    0 ,  20 , 255 ,   0 ,
    0 ,  21 , 255 ,   0 ,
    0 ,  22 , 255 ,   0 ,
    0 ,  23 , 255 ,   0 ,
    0 ,  24 , 255 ,   0 ,
    0 ,  25 , 255 ,   0 ,
    0 ,  26 , 255 ,   0 ,
    0 ,  27 , 255 ,   0 ,
    0 ,  28 , 255 ,   0 ,
    0 ,  29 , 255 ,   0 ,
    0 ,  30 , 255 ,   0 ,
    0 ,  31 , 255 ,   0 ,
    0 ,  32 , 255 ,   0 ,
    0 ,  33 , 255 ,   0 ,
    0 ,  34 , 255 ,   0 ,
    0 ,  35 , 255 ,   0 ,
    0 ,  36 , 255 ,   0 ,
    0 ,  37 , 255 ,   0 ,
    0 ,  38 , 255 ,   0 ,
    0 ,  39 , 255 ,   0 ,
    0 ,  40 , 255 ,   0 ,
    0 ,  41 , 255 ,   0 ,
    0 ,  42 , 255 ,   0 ,
    0 ,  43 , 255 ,   0 ,
    0 ,  44 , 255 ,   0 ,
    0 ,  45 , 255 ,   0 ,
    0 ,  46 , 255 ,   0 ,
    0 ,  47 , 255 ,   0 ,
    0 ,  48 , 255 ,   0 ,
    0 ,  49 , 255 ,   0 ,
    0 ,  50 , 255 ,   0 ,
    0 ,  51 , 255 ,   0 ,
    0 ,  52 , 255 ,   0 ,
    0 ,  53 , 255 ,   0 ,
    0 ,  54 , 255 ,   0 ,
    0 ,  55 , 255 ,   0 ,
    0 ,  56 , 255 ,   0 ,
    0 ,  57 , 255 ,   0 ,
    0 ,  58 , 255 ,   0 ,
    0 ,  59 , 255 ,   0 ,
    0 ,  60 , 255 ,   0 ,
    0 ,  61 , 255 ,   0 ,
    0 ,  62 , 255 ,   0 ,
    0 ,  63 , 255 ,   0 ,
    0 ,  64 , 255 ,   0 ,
    0 ,  65 , 255 ,   0 ,
    0 ,  66 , 255 ,   0 ,
    0 ,  67 , 255 ,   0 ,
    0 ,  68 , 255 ,   0 ,
    0 ,  69 , 255 ,   0 ,
    0 ,  70 , 255 ,   0 ,
    0 ,  71 , 255 ,   0 ,
    0 ,  72 , 255 ,   0 ,
    0 ,  73 , 255 ,   0 ,
    0 ,  74 , 255 ,   0 ,
    0 ,  75 , 255 ,   0 ,
    0 ,  76 , 255 ,   0 ,
    0 ,  77 , 255 ,   0 ,
    0 ,  78 , 255 ,   0 ,
    0 ,  79 , 255 ,   0 ,
    0 ,  80 , 255 ,   0 ,
    0 ,  81 , 255 ,   0 ,
    0 ,  82 , 255 ,   0 ,
    0 ,  83 , 255 ,   0 ,
    0 ,  84 , 255 ,   0 ,
    0 ,  85 , 255 ,   0 ,
    0 ,  86 , 255 ,   0 ,
    0 ,  87 , 255 ,   0 ,
    0 ,  88 , 255 ,   0 ,
    0 ,  89 , 255 ,   0 ,
    0 ,  90 , 255 ,   0 ,
    0 ,  91 , 255 ,   0 ,
    0 ,  92 , 255 ,   0 ,
    0 ,  93 , 255 ,   0 ,
    0 ,  94 , 255 ,   0 ,
    0 ,  95 , 255 ,   0 ,
    0 ,  96 , 255 ,   0 ,
    0 ,  97 , 255 ,   0 ,
    0 ,  98 , 255 ,   0 ,
    0 ,  99 , 255 ,   0 ,
    0 , 100 , 255 ,   0 ,
    0 , 101 , 255 ,   0 ,
    0 , 102 , 255 ,   0 ,
    0 , 103 , 255 ,   0 ,
    0 , 104 , 255 ,   0 ,
    0 , 105 , 255 ,   0 ,
    0 , 106 , 255 ,   0 ,
    0 , 107 , 255 ,   0 ,
    0 , 108 , 255 ,   0 ,
    0 , 109 , 255 ,   0 ,
    0 , 110 , 255 ,   0 ,
    0 , 111 , 255 ,   0 ,
    0 , 112 , 255 ,   0 ,
    0 , 113 , 255 ,   0 ,
    0 , 114 , 255 ,   0 ,
    0 , 115 , 255 ,   0 ,
    0 , 116 , 255 ,   0 ,
    0 , 117 , 255 ,   0 ,
    0 , 118 , 255 ,   0 ,
    0 , 119 , 255 ,   0 ,
    0 , 120 , 255 ,   0 ,
    0 , 121 , 255 ,   0 ,
    0 , 122 , 255 ,   0 ,
    0 , 123 , 255 ,   0 ,
    0 , 124 , 255 ,   0 ,
    0 , 125 , 255 ,   0 ,
    0 , 126 , 255 ,   0 ,
    0 , 127 , 255 ,   0 ,
    0 , 129 , 255 ,   0 ,
    0 , 131 , 255 ,   0 ,
    0 , 133 , 255 ,   0 ,
    0 , 135 , 255 ,   0 ,
    0 , 137 , 255 ,   0 ,
    0 , 139 , 255 ,   0 ,
    0 , 141 , 255 ,   0 ,
    0 , 143 , 255 ,   0 ,
    0 , 145 , 255 ,   0 ,
    0 , 147 , 255 ,   0 ,
    0 , 149 , 255 ,   0 ,
    0 , 151 , 255 ,   0 ,
    0 , 153 , 255 ,   0 ,
    0 , 155 , 255 ,   0 ,
    0 , 157 , 255 ,   0 ,
    0 , 159 , 255 ,   0 ,
    0 , 161 , 255 ,   0 ,
    0 , 163 , 255 ,   0 ,
    0 , 165 , 255 ,   0 ,
    0 , 167 , 255 ,   0 ,
    0 , 169 , 255 ,   0 ,
    0 , 171 , 255 ,   0 ,
    0 , 173 , 255 ,   0 ,
    0 , 175 , 255 ,   0 ,
    0 , 177 , 255 ,   0 ,
    0 , 179 , 255 ,   0 ,
    0 , 181 , 255 ,   0 ,
    0 , 183 , 255 ,   0 ,
    0 , 185 , 255 ,   0 ,
    0 , 187 , 255 ,   0 ,
    0 , 189 , 255 ,   0 ,
    0 , 191 , 255 ,   0 ,
    0 , 193 , 255 ,   0 ,
    0 , 195 , 255 ,   0 ,
    0 , 197 , 255 ,   0 ,
    0 , 199 , 255 ,   0 ,
    0 , 201 , 255 ,   0 ,
    0 , 203 , 255 ,   0 ,
    0 , 205 , 255 ,   0 ,
    0 , 207 , 255 ,   0 ,
    0 , 209 , 255 ,   0 ,
    0 , 211 , 255 ,   0 ,
    0 , 213 , 255 ,   0 ,
    0 , 215 , 255 ,   0 ,
    0 , 217 , 255 ,   0 ,
    0 , 219 , 255 ,   0 ,
    0 , 221 , 255 ,   0 ,
    0 , 223 , 255 ,   0 ,
    0 , 225 , 255 ,   0 ,
    0 , 227 , 255 ,   0 ,
    0 , 229 , 255 ,   0 ,
    0 , 231 , 255 ,   0 ,
    0 , 233 , 255 ,   0 ,
    0 , 235 , 255 ,   0 ,
    0 , 237 , 255 ,   0 ,
    0 , 239 , 255 ,   0 ,
    0 , 241 , 255 ,   0 ,
    0 , 243 , 255 ,   0 ,
    0 , 245 , 255 ,   0 ,
    0 , 247 , 255 ,   0 ,
    0 , 249 , 255 ,   0 ,
    0 , 251 , 255 ,   0 ,
    0 , 253 , 255 ,   0 ,
    0 , 255 , 255 ,   0 ,
    1 ,   1 , 255 ,   0 ,
    1 ,   3 , 255 ,   0 ,
    1 ,   5 , 255 ,   0 ,
    1 ,   7 , 255 ,   0 ,
    1 ,   9 , 255 ,   0 ,
    1 ,  11 , 255 ,   0 ,
    1 ,  13 , 255 ,   0 ,
    1 ,  15 , 255 ,   0 ,
    1 ,  17 , 255 ,   0 ,
    1 ,  19 , 255 ,   0 ,
    1 ,  21 , 255 ,   0 ,
    1 ,  23 , 255 ,   0 ,
    1 ,  25 , 255 ,   0 ,
    1 ,  27 , 255 ,   0 ,
    1 ,  29 , 255 ,   0 ,
    1 ,  31 , 255 ,   0 ,
    1 ,  33 , 255 ,   0 ,
    1 ,  35 , 255 ,   0 ,
    1 ,  37 , 255 ,   0 ,
    1 ,  39 , 255 ,   0 ,
    1 ,  41 , 255 ,   0 ,
    1 ,  43 , 255 ,   0 ,
    1 ,  45 , 255 ,   0 ,
    1 ,  47 , 255 ,   0 ,
    1 ,  49 , 255 ,   0 ,
    1 ,  51 , 255 ,   0 ,
    1 ,  53 , 255 ,   0 ,
    1 ,  55 , 255 ,   0 ,
    1 ,  57 , 255 ,   0 ,
    1 ,  59 , 255 ,   0 ,
    1 ,  61 , 255 ,   0 ,
    1 ,  63 , 255 ,   0 ,
    1 ,  65 , 255 ,   0 ,
    1 ,  67 , 255 ,   0 ,
    1 ,  69 , 255 ,   0 ,
    1 ,  71 , 255 ,   0 ,
    1 ,  73 , 255 ,   0 ,
    1 ,  75 , 255 ,   0 ,
    1 ,  77 , 255 ,   0 ,
    1 ,  79 , 255 ,   0 ,
    1 ,  81 , 255 ,   0 ,
    1 ,  83 , 255 ,   0 ,
    1 ,  85 , 255 ,   0 ,
    1 ,  87 , 255 ,   0 ,
    1 ,  89 , 255 ,   0 ,
    1 ,  91 , 255 ,   0 ,
    1 ,  93 , 255 ,   0 ,
    1 ,  95 , 255 ,   0 ,
    1 ,  97 , 255 ,   0 ,
    1 ,  99 , 255 ,   0 ,
    1 , 101 , 255 ,   0 ,
    1 , 103 , 255 ,   0 ,
    1 , 105 , 255 ,   0 ,
    1 , 107 , 255 ,   0 ,
    1 , 109 , 255 ,   0 ,
    1 , 111 , 255 ,   0 ,
    1 , 113 , 255 ,   0 ,
    1 , 115 , 255 ,   0 ,
    1 , 117 , 255 ,   0 ,
    1 , 119 , 255 ,   0 ,
    1 , 121 , 255 ,   0 ,
    1 , 123 , 255 ,   0 ,
    1 , 125 , 255 ,   0 ,
    1 , 127 , 255 ,   0
};
#endif // APDK_AUTODUPLEX

APDK_END_NAMESPACE
